@@ -374,7 +374,9 @@ class Command(BaseCommand):
     from the third-party sources. If the checklist has already been loaded
     then it will be updated, tracking any changes made at the source. The
     status report will contain a short description of any changes made such
-    as entries being added or a count changed.
+    as entries being added or a count changed. When a checklist has been
+    loaded successfully the file is deleted so the directory does not fill
+    up with files.
     """
     option_list = BaseCommand.option_list + (
         make_option(
@@ -411,6 +413,7 @@ class Command(BaseCommand):
                     self.denormalize_values(values)
                     self.add_or_update_checklist(values, messages)
                     passed.append((path, values, messages))
+                    os.remove(path)
             except:
                 kind, value, trace = sys.exc_info()
                 error = traceback.format_exception(kind, value, trace)
