@@ -28,6 +28,7 @@ from django.db.models import Model, BooleanField, IntegerField, \
     ForeignKey, OneToOneField, ManyToManyField, PROTECT, SET_NULL, \
     PositiveIntegerField
 from django.template.defaultfilters import slugify
+from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes.models import ContentType
 
@@ -468,7 +469,7 @@ class Checklist(ChecklistsModel):
 
     include = BooleanField(default=False)
     complete = BooleanField(default=False)
-    added_on = DateField(db_index=True, default=date.today)
+    added_on = DateField(db_index=True, default=timezone.now().date)
     location = ForeignKey(Location, on_delete=PROTECT)
     date = DateField(db_index=True)
     activity = ForeignKey(Activity, blank=True, null=True)
